Common Partial-Wave-Analysis Framework (ComPWA) {#mainpage}
===========================================================

Welcome to the class documentation of ComPWA!

These pages are useful if you are working on the C++ backend of the %ComPWA framework. See [the repository on GitHub](https://github.com/ComPWA/ComPWA) for the source code.

ComPWA is best used through it's python interface (`pycompwa`). You can find all installation instructions and usage examples on our website, [compwa.github.io](https://compwa.github.io/).